@@ -17,16 +17,8 @@ sys.path.append(os.path.join(os.path.dirname(__file__), ".."))  # noqa: WPS221
 
 from cli_calc.cli_output import Output  # pylint: disable=C0413  # noqa: E402
 from cli_calc.config import Config  # pylint: disable=C0413  # noqa: E402
+from cli_calc.input import Input  # pylint: disable=C0413  # noqa: E402
 from cli_calc.memory import Memory  # pylint: disable=C0413  # noqa: E402
-from cli_calc.read_line_parser import (  # pylint: disable=C0413  # noqa: E402
-    ReadLineParser,
-)
-
-
-def cli_start() -> None:  # pragma: no cover
-    """Prepare the CLI."""
-    Output.print_help()
-    Output.print_line()
 
 
 def io_loop() -> None:  # pragma: no cover
@@ -37,7 +29,7 @@ def io_loop() -> None:  # pragma: no cover
     """
     try:
         while True:  # noqa: WPS457
-            ReadLineParser.input_cli()
+            Input.get_line()
             Output.print_line()
     except KeyboardInterrupt:
         sys.exit(0)
@@ -46,7 +38,7 @@ def io_loop() -> None:  # pragma: no cover
 def main() -> None:  # pragma: no cover
     """Main."""
     Config.init(Memory.value_dict)
-    cli_start()
+    Input.init_output()
     io_loop()
 
 
